summaryrefslogtreecommitdiffstats
path: root/src/tools
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2025-06-13 15:22:11 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2025-07-27 12:35:23 +0900
commitd346b0f7afcf92a76466c5aaff5fed80d74dcb59 (patch)
treed80acbed6056b2cf501f717c294f572d91dbc0f2 /src/tools
parent9dd062934387e59553bfea7402e840ee487aca77 (diff)
downloadtqt-d346b0f7afcf92a76466c5aaff5fed80d74dcb59.tar.gz
tqt-d346b0f7afcf92a76466c5aaff5fed80d74dcb59.zip
Rename 'guiThread' and related functions to 'coreThread'.
A TTY TQApplication is GUI-less, so the usage of the term 'GUI' is misleading. Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it>
Diffstat (limited to 'src/tools')
-rw-r--r--src/tools/tqthreadinstance_p.h2
-rw-r--r--src/tools/tqthreadstorage_unix.cpp8
2 files changed, 5 insertions, 5 deletions
diff --git a/src/tools/tqthreadinstance_p.h b/src/tools/tqthreadinstance_p.h
index 2778d5daa..ea34f3c5f 100644
--- a/src/tools/tqthreadinstance_p.h
+++ b/src/tools/tqthreadinstance_p.h
@@ -100,7 +100,7 @@ public:
static void finish( TQThreadInstance * );
#endif // Q_OS_WIN32
- static void finishGuiThread( TQThreadInstance *d );
+ static void finishCoreThread( TQThreadInstance *d );
TQEventLoop* eventLoop;
int cleanupType;
diff --git a/src/tools/tqthreadstorage_unix.cpp b/src/tools/tqthreadstorage_unix.cpp
index 977ccf6bb..71b10822b 100644
--- a/src/tools/tqthreadstorage_unix.cpp
+++ b/src/tools/tqthreadstorage_unix.cpp
@@ -90,14 +90,14 @@ TQThreadStorageData::TQThreadStorageData( void (*func)( void * ) )
TQThreadStorageData::~TQThreadStorageData()
{
// The Gui thread has static storage duration, TQThreadStorage are almost always static (it's
// technically possible to allocate those in the heap, but it's quite unusual). It's impossible
// to predict whichever of those one gets destroyed first, but usually it's a TQThreadStorage.
// In that case we have to do the cleanup of its storage ourself as it won't be possible after
// nullifying the destructor below.
- TQThread *guiThread = TQApplication::guiThread();
- if (guiThread) {
- TQThreadInstance *d = guiThread->d;
+ TQThread *coreThread = TQApplication::coreThread();
+ if (coreThread) {
+ TQThreadInstance *d = coreThread->d;
TQMutexLocker locker( d->mutex() );
if (d->thread_storage && d->thread_storage[id]) {
thread_storage_usage[id].func( d->thread_storage[id] );
@@ -90,14 +90,14 @@ TQThreadStorageData::TQThreadStorageData( void (*func)( void * ) )
TQThreadStorageData::~TQThreadStorageData()
{
- // The Gui thread has static storage duration, TQThreadStorage are almost always static (it's
+ // The core thread has static storage duration, TQThreadStorage are almost always static (it's
// technically possible to allocate those in the heap, but it's quite unusual). It's impossible
// to predict whichever of those one gets destroyed first, but usually it's a TQThreadStorage.